# dbconn

## 项目目的
把数据库连接信息独立出来，放在一个专用的配置目录下。可以提供以下好处：

* 代码中不再包含连接信息，方便做到开发和运维分离。
* 代码中没有连接信息，也提高了安全性，避免不小心分发出去的代码泄露了秘密。
* 后续数据库变换地址、连接方式、修改密码不再需要调整源代码，直接修改配置即可。
* 同一份源代码，无须变动，即可适应生产、测试环境。
* 数据库定期修改密码时，仅需要改动少量配置文件。

## 一些特性

* 支持不同的语言，初期支持python、c

# 快速入门

## 安装

使用
```
pip install dbconn
```
即可下载安装
